vbvarsel.global_parameters — vbvarsel 0.0.1 documentation

# vbvarsel.global_parameters

## Classes

`Hyperparameters` | Class representing the hyperparameters for the simulation.
`SimulationParameters` | Class representing the simulation parameters.

## Module Contents

class vbvarsel.global_parameters.Hyperparameters

  Class representing the hyperparameters for the simulation.

  threshold: float = 0.1
  k1: int = 5
  alpha0: float
  a0: int = 3
  beta0: float = 0.001
  d0: int = 1
  t_max: int = 1
  max_itr: int = 25
  max_annealed_itr: int = 10
  max_models: int = 10
  __post_init__()

class vbvarsel.global_parameters.SimulationParameters

  Class representing the simulation parameters.

  These parameters are the “settings” for the simulation experiment. For more information regarding the simulation, see [INSERT PAPER HERE]. Mixture proportions must be numbers between 0 and 1. The n_relevants array must be all numbers that are less than the n_variables value, as it is not possible to have a higher number of relevant variables than total variables.

  n_observations: list[int]
  n_variables: int = 200
  n_relevants: list[int]
  mixture_proportions: list[float]
  means: list[int]